@@ -18,6 +18,11 @@ DEFAULT_FLUSH_INTERVAL = 5.0
 logging.addLevelName(DONE_LEVEL_NUM, 'DONE')
 logging.addLevelName(START_LEVEL_NUM, 'START')
 
+if hasattr(random, 'choices'):
+    random_choices = random.choices
+else:
+    from watchtower_logging.utils import random_choices
+
 class logLevels(object):
 
     DEBUG = logging.DEBUG
@@ -83,7 +88,7 @@ def critical(self, msg, *args, data=None, **kws):
 
 def setExecutionId(self, execution_id=None):
     if execution_id is None:
-        self._execution_id = ''.join(random.choices(string.ascii_lowercase + string.digits, k=EXECUTION_ID_LENGTH))
+        self._execution_id = ''.join(random_choices(string.ascii_lowercase + string.digits, k=EXECUTION_ID_LENGTH))
     else:
         self._execution_id = execution_id
 
